@@ -58,7 +58,7 @@ class CustomPoliciesIntegration(BaseIntegrationFeature):
 
     def _get_policies_from_platform(self):
         headers = merge_dicts(get_default_get_headers(self.bc_integration.bc_source, self.bc_integration.bc_source_version),
-                              get_auth_header(self.bc_integration.bc_api_key))
+                              get_auth_header(self.bc_integration.get_auth_token()))
         response = requests.request('GET', self.policies_url, headers=headers)
 
         if response.status_code != 200:
