@@ -20,7 +20,19 @@ from termcolor import colored
 from tqdm import trange
 from urllib3.exceptions import HTTPError
 
-from checkov.common.bridgecrew.ci_variables import *
+from checkov.common.bridgecrew.ci_variables import (
+    BC_TO_BRANCH,
+    BC_PR_ID,
+    BC_PR_URL,
+    BC_COMMIT_HASH,
+    BC_COMMIT_URL,
+    BC_AUTHOR_NAME,
+    BC_AUTHOR_URL,
+    BC_RUN_ID,
+    BC_RUN_URL,
+    BC_REPOSITORY_URL,
+    BC_FROM_BRANCH,
+)
 from checkov.common.bridgecrew.platform_errors import BridgecrewAuthError
 from checkov.common.bridgecrew.platform_key import read_key, persist_key, bridgecrew_file
 from checkov.common.bridgecrew.wrapper import reduce_scan_reports, persist_checks_results, \
@@ -30,6 +42,8 @@ from checkov.common.runners.base_runner import filter_ignored_paths
 from checkov.common.util.http_utils import normalize_prisma_url
 from checkov.version import version as checkov_version
 
+SLEEP_SECONDS = 1
+
 EMAIL_PATTERN = r"[^@]+@[^@]+\.[^@]+"
 UUID_V4_PATTERN = r"^[0-9a-f]{8}\b-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-\b[0-9a-f]{12}$"
 
@@ -38,7 +52,7 @@ ACCOUNT_CREATION_TIME = 180  # in seconds
 UNAUTHORIZED_MESSAGE = 'User is not authorized to access this resource with an explicit deny'
 
 DEFAULT_REGION = "us-west-2"
-MAX_RETRIES = 10
+MAX_RETRIES = 40
 ONBOARDING_SOURCE = "checkov"
 
 SIGNUP_HEADER = {
@@ -157,7 +171,6 @@ class BcPlatformIntegration(object):
                                               aws_session_token=self.credentials["SessionToken"],
                                               region_name=DEFAULT_REGION
                                               )
-                sleep(10)  # Wait for the policy to update
                 self.platform_integration_configured = True
                 self.use_s3_integration = True
             except HTTPError as e:
@@ -299,15 +312,15 @@ class BcPlatformIntegration(object):
                     logging.info(f"Finalize repository {self.repo_id} in bridgecrew's platform")
                 elif try_num < MAX_RETRIES and re.match('The integration ID .* in progress',
                                                         response.get('message', '')):
-                    logging.info(f"Failed to persist for repo {self.repo_id}, sleeping for 2 seconds before retrying")
+                    logging.info(f"Failed to persist for repo {self.repo_id}, sleeping for {SLEEP_SECONDS} seconds before retrying")
                     try_num += 1
-                    sleep(3)
+                    sleep(SLEEP_SECONDS)
                 else:
                     raise Exception(
                         f"Failed to finalize repository {self.repo_id} in bridgecrew's platform\n{response}")
 
     def _persist_file(self, full_file_path, relative_file_path):
-        tries = 4
+        tries = MAX_RETRIES
         curr_try = 0
         file_object_key = os.path.join(self.repo_path, relative_file_path).replace("\\", "/")
         while curr_try < tries:
@@ -316,7 +329,7 @@ class BcPlatformIntegration(object):
                 return
             except ClientError as e:
                 if e.response.get('Error', {}).get('Code') == 'AccessDenied':
-                    sleep(5)
+                    sleep(SLEEP_SECONDS)
                     curr_try += 1
                 else:
                     logging.error(f"failed to persist file {full_file_path} into S3 bucket {self.bucket}\n{e}")
@@ -345,7 +358,7 @@ class BcPlatformIntegration(object):
 
     def get_checkov_mapping_metadata(self) -> Optional[dict]:
         if self.bc_skip_mapping is True:
-            logging.debug(f"Skipped mapping API call")
+            logging.debug("Skipped mapping API call")
             self.ckv_to_bc_id_mapping = {}
             return
         guidelines_url = self.guidelines_api_url
@@ -361,7 +374,7 @@ class BcPlatformIntegration(object):
             self.guidelines = response["guidelines"]
             self.bc_id_mapping = response.get("idMapping")
             self.ckv_to_bc_id_mapping = {ckv_id: bc_id for (bc_id, ckv_id) in self.bc_id_mapping.items()}
-            logging.debug(f"Got checkov mappings from Bridgecrew BE")
+            logging.debug("Got checkov mappings from Bridgecrew BE")
         except Exception as e:
             logging.debug(f"Failed to get the guidelines from {guidelines_url}, error:\n{e}")
             self.ckv_to_bc_id_mapping = {}
@@ -370,7 +383,7 @@ class BcPlatformIntegration(object):
     def onboarding(self):
         if not self.bc_api_key:
             print(Style.BRIGHT + colored("\nWould you like to “level up” your Checkov powers for free?  The upgrade includes: \n\n", 'green',
-                                         attrs=['bold'])  + colored(
+                                         attrs=['bold']) + colored(
                 u"\u2022 " + "Command line docker Image scanning\n"
                 u"\u2022 " + "Free (forever) bridgecrew.cloud account with API access\n"
                 u"\u2022 " + "Auto-fix remediation suggestions\n"
@@ -558,7 +571,7 @@ class BcPlatformIntegration(object):
             for _ in t:
                 t.set_description(msg)
                 t.set_postfix(refresh=False)
-                sleep(1)
+                sleep(SLEEP_SECONDS)
 
     def get_excluded_paths(self):
         repo_settings_api_url = f'{self.api_url}/api/v1/vcs/settings/scheme'
