@@ -1,3 +1,4 @@
+import itertools
 from typing import Optional, Tuple, List, Dict, Any
 
 from networkx import DiGraph
@@ -11,6 +12,7 @@ class BaseGraphCheck:
         self.id = ""
         self.bc_id = None
         self.name = ""
+        self.category = ""
         self.resource_types: List[str] = []
         self.connected_resources_types: List[str] = []
         self.operator = ""
@@ -19,6 +21,7 @@ class BaseGraphCheck:
         self.sub_checks: List["BaseGraphCheck"] = []
         self.type: Optional[SolverType] = None
         self.solver: Optional[BaseSolver] = None
+        self.guideline: Optional[str] = None
 
     def set_solver(self, solver: BaseSolver) -> None:
         self.solver = solver
@@ -28,3 +31,8 @@ class BaseGraphCheck:
 
     def get_output_id(self, use_bc_ids: bool) -> str:
         return self.bc_id if self.bc_id and use_bc_ids else self.id
+
+    def get_evaluated_keys(self) -> List[str]:
+        if self.sub_checks:
+            return list(set(itertools.chain.from_iterable(check.get_evaluated_keys() for check in self.sub_checks)))
+        return ["/".join(self.attribute.split('.'))] if self.attribute else []
