@@ -19,11 +19,15 @@ class GoogleComputeShieldedVM(BaseResourceCheck):
         """
 
         if 'shielded_instance_config' in conf.keys():
+            self.evaluated_keys = ['shielded_instance_config', 'shielded_instance_config/[0]/enable_vtpm',
+                                   'shielded_instance_config/[0]/enable_integrity_monitoring']
             if 'enable_vtpm' in conf['shielded_instance_config'][0] and \
                     not conf['shielded_instance_config'][0]['enable_vtpm'][0]:
+                self.evaluated_keys = ['shielded_instance_config/[0]/enable_vtpm']
                 return CheckResult.FAILED
             if 'enable_integrity_monitoring' in conf['shielded_instance_config'][0] and \
                     not conf['shielded_instance_config'][0]['enable_integrity_monitoring'][0]:
+                self.evaluated_keys = ['shielded_instance_config/[0]/enable_integrity_monitoring']
                 return CheckResult.FAILED
             return CheckResult.PASSED
         return CheckResult.FAILED
